# Lyric - Scraper

###Lyric-Scraper is a tool to get lyrics for your favourite songs.

## Features

* Can scrape the lyrics from the web by entering Artist and song details.
* Can get the lyrics from meta data of song file.
* Can save the lyrics in file meta data or in text file.
### How To Install
you can directly install from pip.
```
pip3 install LyricScraper
```
###OR
1.) clone this repository
 ```
git clone https://github.com/prakhar1965/lyric-scrapper.git
```
2.) Enter into repo's directory
```
cd LyricScraper
```
3.)Install the require dependencies by running 
```
pip install -r requirements.txt
```
3.)Install lyric-scrapper by running 
```
python setup.py install
```
### How To Use
* Enter `lyrics` to command prompt, It will ask for artist and song details.
* Enter `lyrics [FILENAMES]`, to get lyric from song MP3 file.
* Check out different options, by enter `lyrics --help`


## License

This project is licensed under the MIT License - see the [LICENSE.txt](LICENSE.txt) file for details


